@@ -17,11 +17,11 @@ print("sub grid size = " + str(sub_size))
 print("circular mask radius = " + str(radius) + "\n")
 
 
-mask = aa.mask.circular(
+mask = aa.Mask.circular(
     shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=sub_size, radius=radius
 )
 
-grid = aa.grid.from_mask(mask=mask)
+grid = aa.Grid.from_mask(mask=mask)
 
 print("Number of points = " + str(grid.sub_shape_1d) + "\n")
 
