@@ -19,7 +19,7 @@ def reset_config():
 class TestGalaxyFitData:
     def test__image_noise_map_and_mask(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_image=True
         )
 
@@ -79,7 +79,7 @@ class TestGalaxyFitData:
 
     def test__grid(self, gal_data_7x7, sub_mask_7x7, sub_grid_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_image=True
         )
 
@@ -87,18 +87,18 @@ class TestGalaxyFitData:
 
     def test__pixel_scale_interpolation_grid(self, image_7x7, sub_mask_7x7):
 
-        noise_map = aa.array.full(fill_value=2.0, shape_2d=(7, 7), pixel_scales=3.0)
-        gal_data_7x7 = aast.galaxy_data(
+        noise_map = aa.Array.full(fill_value=2.0, shape_2d=(7, 7), pixel_scales=3.0)
+        gal_data_7x7 = aast.GalaxyData(
             image=image_7x7, noise_map=noise_map, pixel_scales=3.0
         )
-        gal_data_7x7 = aast.masked_galaxy_data(
+        gal_data_7x7 = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7,
             mask=sub_mask_7x7,
             pixel_scale_interpolation_grid=1.0,
             use_image=True,
         )
 
-        grid = aa.masked_grid.from_mask(mask=sub_mask_7x7)
+        grid = aa.MaskedGrid.from_mask(mask=sub_mask_7x7)
         new_grid = grid.new_grid_with_interpolator(pixel_scale_interpolation_grid=1.0)
         assert (gal_data_7x7.grid == new_grid).all()
         assert (gal_data_7x7.grid.interpolator.vtx == new_grid.interpolator.vtx).all()
@@ -106,7 +106,7 @@ class TestGalaxyFitData:
 
     def test__gal_data_7x7_image(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_image=True
         )
 
@@ -180,7 +180,7 @@ class TestGalaxyFitData:
 
     def test__gal_data_7x7_convergence(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_convergence=True
         )
 
@@ -258,7 +258,7 @@ class TestGalaxyFitData:
 
     def test__gal_data_7x7_potential(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_potential=True
         )
 
@@ -334,7 +334,7 @@ class TestGalaxyFitData:
 
     def test__gal_data_7x7_deflections_y(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_deflections_y=True
         )
         assert galaxy_fit_data.pixel_scales == (1.0, 1.0)
@@ -423,7 +423,7 @@ class TestGalaxyFitData:
 
     def test__gal_data_7x7_deflections_x(self, gal_data_7x7, sub_mask_7x7):
 
-        galaxy_fit_data = aast.masked_galaxy_data(
+        galaxy_fit_data = aast.MaskedGalaxyDataset(
             galaxy_data=gal_data_7x7, mask=sub_mask_7x7, use_deflections_x=True
         )
 
@@ -515,23 +515,23 @@ class TestGalaxyFitData:
         self, image_7x7, noise_map_7x7, sub_mask_7x7
     ):
 
-        gal_data_7x7 = aast.galaxy_data(
+        gal_data_7x7 = aast.GalaxyData(
             image=image_7x7, noise_map=noise_map_7x7, pixel_scales=3.0
         )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(galaxy_data=gal_data_7x7, mask=sub_mask_7x7)
+            aast.MaskedGalaxyDataset(galaxy_data=gal_data_7x7, mask=sub_mask_7x7)
 
     def test__multiple_use_methods__raises_exception(
         self, image_7x7, noise_map_7x7, sub_mask_7x7
     ):
 
-        gal_data_7x7 = aast.galaxy_data(
+        gal_data_7x7 = aast.GalaxyData(
             image=image_7x7, noise_map=noise_map_7x7, pixel_scales=3.0
         )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(
+            aast.MaskedGalaxyDataset(
                 galaxy_data=gal_data_7x7,
                 mask=sub_mask_7x7,
                 use_image=True,
@@ -539,7 +539,7 @@ class TestGalaxyFitData:
             )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(
+            aast.MaskedGalaxyDataset(
                 galaxy_data=gal_data_7x7,
                 mask=sub_mask_7x7,
                 use_image=True,
@@ -547,7 +547,7 @@ class TestGalaxyFitData:
             )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(
+            aast.MaskedGalaxyDataset(
                 galaxy_data=gal_data_7x7,
                 mask=sub_mask_7x7,
                 use_image=True,
@@ -555,7 +555,7 @@ class TestGalaxyFitData:
             )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(
+            aast.MaskedGalaxyDataset(
                 galaxy_data=gal_data_7x7,
                 mask=sub_mask_7x7,
                 use_image=True,
@@ -564,7 +564,7 @@ class TestGalaxyFitData:
             )
 
         with pytest.raises(exc.GalaxyException):
-            aast.masked_galaxy_data(
+            aast.MaskedGalaxyDataset(
                 galaxy_data=gal_data_7x7,
                 mask=sub_mask_7x7,
                 use_image=True,
